Skip to contents

The former manual builder duplicated the package configure path and could mutate an installed package tree. Build Rduckhts from a source tarball with R CMD build and install that tarball instead.

Usage

duckhts_build(build_dir = NULL, make = NULL, force = FALSE, verbose = TRUE)

Arguments

build_dir

Retained for source compatibility; ignored.

make

Retained for source compatibility; ignored.

force

Retained for source compatibility; ignored.

verbose

Retained for source compatibility; ignored.

Value

This function always raises an error.