Returns the version and build features reported by the htslib library that is actually loaded with DuckHTS.
Examples
if (FALSE) { # \dontrun{
con <- rduckhts_connect()
rduckhts_htslib_info(con)
DBI::dbDisconnect(con, shutdown = TRUE)
} # }
Returns the version and build features reported by the htslib library that is actually loaded with DuckHTS.
if (FALSE) { # \dontrun{
con <- rduckhts_connect()
rduckhts_htslib_info(con)
DBI::dbDisconnect(con, shutdown = TRUE)
} # }