Loads the DuckHTS extension into an existing DuckDB connection. This must be
called before using HTS reader functions on a connection not created by
rduckhts_connect().
Details
The connection must permit unsigned extension loading. With current versions
of the duckdb R package, its driver must also permit extension loading.
Prefer rduckhts_connect() when Rduckhts owns the connection.
Examples
con <- rduckhts_connect()
DBI::dbDisconnect(con, shutdown = TRUE)